.. _integration_test_report_itest_lin:

=====================================
Integration test report for itest_lin
=====================================

.. contents:: `Contents`
    :depth: 2
    :local:


.. item:: REPORT_ITEST_LIN-FIRST_TEST Test report for ITEST_LIN-FIRST_TEST
    :fails: ITEST_LIN-FIRST_TEST

    Test result: Fail

.. item:: REPORT_ITEST_LIN-AN_UNLINKED_TEST Test report for ITEST_LIN-AN_UNLINKED_TEST
    :passes: ITEST_LIN-AN_UNLINKED_TEST

    Test result: Pass

.. item:: REPORT_ITEST_LIN-ANOTHER_TEST Test report for ITEST_LIN-ANOTHER_TEST
    :passes: ITEST_LIN-ANOTHER_TEST

    Test result: Pass

Traceability matrix
===================

The below table traces the test report to test cases.

.. item-matrix:: Linking these integration test reports to integration test cases
    :source: REPORT_ITEST_LIN-
    :target: ITEST_LIN-
    :sourcetitle: Integration test report
    :targettitle: Integration test specification
    :type: fails passes
    :stats:
    :group:
    :nocaptions:
